@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdlib.h 2503 2016-02-07 22:59:47Z joerg_wunsch $
+  $Id: stdlib.h 2524 2016-09-07 12:08:25Z joerg_wunsch $
 */
 
 #ifndef _STDLIB_H_
@@ -349,6 +349,15 @@ extern void *realloc(void *__ptr, size_t __size) __ATTR_MALLOC__;
 
 extern double strtod(const char *__nptr, char **__endptr);
 
+/** \ingroup avr_stdlib
+    \fn  double atof (const char *nptr)
+
+    The atof() function converts the initial portion of the string pointed
+    to by \a nptr to double representation.
+
+    It is equivalent to calling
+	\code strtod(nptr, (char **)0); \endcode
+ */
 extern double atof(const char *__nptr);
 
 /** Highest number that can be generated by rand(). */
@@ -625,14 +634,14 @@ extern long random_r(unsigned long *__ctx);
    one digit before the decimal-point character and the number of
    digits after it is equal to the precision \c prec; if the precision
    is zero, no decimal-point character appears.  If \c flags has the
-   DTOSTRE_UPPERCASE bit set, the letter \c 'E' (rather than \c 'e' ) will be
+   DTOSTR_UPPERCASE bit set, the letter \c 'E' (rather than \c 'e' ) will be
    used to introduce the exponent.  The exponent always contains two
    digits; if the value is zero, the exponent is \c "00".
 
-   If \c flags has the DTOSTRE_ALWAYS_SIGN bit set, a space character
+   If \c flags has the DTOSTR_ALWAYS_SIGN bit set, a space character
    will be placed into the leading position for positive numbers.
 
-   If \c flags has the DTOSTRE_PLUS_SIGN bit set, a plus sign will be
+   If \c flags has the DTOSTR_PLUS_SIGN bit set, a plus sign will be
    used instead of a space character in this case.
 
    The dtostre() function returns the pointer to the converted string \c s.
